.. slick documentation master file, created by
   sphinx-quickstart on Fri Jan 18 09:13:18 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to slick's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2
   :numbered:




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

